@@ -1,6 +1,7 @@
 # Orca
 #
-# Copyright 2006-2008 Sun Microsystems Inc.
+# Copyright 2006-2009 Sun Microsystems Inc.
+# Copyright 2010 Joanmarie Diggs
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -20,7 +21,8 @@
 __id__        = "$Id$"
 __version__   = "$Revision$"
 __date__      = "$Date$"
-__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
+__copyright__ = "Copyright (c) 2005-2009 Sun Microsystems Inc., "  \
+                "Copyright (c) 2010 Joanmarie Diggs"
 __license__   = "LGPL"
 
 import pyatspi
@@ -29,11 +31,10 @@ import orca.default as default
 import orca.input_event as input_event
 import orca.orca as orca
 import orca.orca_state as orca_state
-import orca.keybindings as keybindings
 
-from braillegenerator import BrailleGenerator
-from speechgenerator import SpeechGenerator
-from where_am_I import WhereAmI
+from script_utilities import Utilities
+from speech_generator import SpeechGenerator
+from formatting import Formatting
 
 ########################################################################
 #                                                                      #
@@ -51,78 +52,67 @@ class Script(default.Script):
         """
         default.Script.__init__(self, app)
 
-    def getWhereAmI(self):
-        """Returns the "where am I" class for this script.
-        """
-        return WhereAmI(self)
-
-    def getBrailleGenerator(self):
-        """Returns the braille generator for this script.
-        """
-        return BrailleGenerator(self)
+        # Some objects which issue descendant changed events lack
+        # STATE_MANAGES_DESCENDANTS. As a result, onSelectionChanged
+        # doesn't ignore these objects. That in turn causes Orca to
+        # double-speak some items and/or set the locusOfFocus to a
+        # parent it shouldn't. See bgo#616582. [[[TODO - JD: remove
+        # this hack if and when we get a fix for that bug]]]
+        # 
+        self.lastDescendantChangedSource = None
 
     def getSpeechGenerator(self):
-        """Returns the braille generator for this script.
-        """
+        """Returns the speech generator for this script."""
         return SpeechGenerator(self)
 
-    def consumesKeyboardEvent(self, keyboardEvent):
-        """Called when a key is pressed on the keyboard.
+    def getFormatting(self):
+        """Returns the formatting strings for this script."""
+        return Formatting(self)
+
+    def getUtilities(self):
+        """Returns the utilites for this script."""
+        return Utilities(self)
+
+    def checkKeyboardEventData(self, keyboardEvent):
+        """Checks the data on the keyboard event.
+
+        Some toolkits don't fill all the key event fields, and/or fills
+        them out with unexpected data. This method tries to fill in the
+        missing fields and validate/standardize the data we've been given.
+        While any script can override this method, it is expected that
+        this will only be done at the toolkit script level.
 
         Arguments:
         - keyboardEvent: an instance of input_event.KeyboardEvent
-
-        Returns True if the event is of interest.
         """
 
-        # The Java platform chooses to give us keycodes different from
-        # the native platform keycodes.  So, we hack here by converting
-        # the keysym we get from Java into a keycode.
+        default.Script.checkKeyboardEventData(self, keyboardEvent)
 
-        keysym = keyboardEvent.event_string
+        if not keyboardEvent.keyval_name:
+            return
 
-        # We need to make sure we have a keysym-like thing.  The space
-        # character is not a keysym, so we convert it into the string,
-        # 'space', which is.
+        import gtk.gdk as gdk
+
+        # Standardize the hw_code from a Java-unique one to a gdk one.
         #
-        if keysym == " ":
-            keysym = "space"
-
-        keyboardEvent.hw_code = keybindings.getKeycode(keysym)
-        return default.Script.consumesKeyboardEvent(self, keyboardEvent)
-
-    def getNodeLevel(self, obj):
-        """Determines the node level of this object if it is in a tree
-        relation, with 0 being the top level node.  If this object is
-        not in a tree relation, then -1 will be returned.
-
-        Arguments:
-        -obj: the Accessible object
-        """
-
-        if not obj:
-            return -1
-
-        treeLikeThing = self.getAncestor(obj,
-                                         [pyatspi.ROLE_TREE,
-                                          pyatspi.ROLE_TABLE,
-                                          pyatspi.ROLE_TREE_TABLE],
-                                         None)
-        if not treeLikeThing:
-            return -1
-
-        count = 0
-        while True:
-            state = obj.getState()
-            if state.contains(pyatspi.STATE_EXPANDABLE) \
-               or state.contains(pyatspi.STATE_COLLAPSED):
-                if state.contains(pyatspi.STATE_VISIBLE):
-                    count += 1
-                obj = obj.parent
-            else:
+        keymap = gdk.keymap_get_default()
+        keyval = gdk.keyval_from_name(keyboardEvent.keyval_name)
+        entries = keymap.get_entries_for_keyval(keyval)
+        for entry in entries:
+            if entry[1] == 0:  # group = 0
+                keyboardEvent.hw_code = entry[0]
                 break
 
-        return count - 1
+        # Put the event_string back to what it was prior to the Java
+        # Atk Wrapper hack which gives us the keyname and not the
+        # expected and needed printable character for punctuation
+        # marks.
+        #
+        if keyboardEvent.event_string == keyboardEvent.keyval_name \
+           and len(keyboardEvent.event_string) > 1:
+            keyval = gdk.keyval_from_name(keyboardEvent.keyval_name)
+            if 0 < keyval < 256:
+                keyboardEvent.event_string = unichr(keyval).encode("UTF-8")
 
     def onFocus(self, event):
         """Called whenever an object gets focus.
@@ -133,6 +123,19 @@ class Script(default.Script):
 
         role = event.source.getRole()
 
+        # Ignore bogus/senseless focus claims because they just cause us to
+        # be more chatty as a result of the event and then later as a result
+        # of the changed locusOfFocus.
+        #
+        if role == pyatspi.ROLE_ROOT_PANE:
+            return
+
+        if role == pyatspi.ROLE_PAGE_TAB_LIST and orca_state.locusOfFocus \
+           and orca_state.locusOfFocus.getRole() == pyatspi.ROLE_PAGE_TAB \
+           and orca_state.locusOfFocus.getState().\
+               contains(pyatspi.STATE_FOCUSED):
+            return
+
         if role == pyatspi.ROLE_MENU:
             # Override default.py's onFocus decision to ignore focus
             # events on MENU items with selected children.  This is
@@ -158,6 +161,8 @@ class Script(default.Script):
         - event: the Event
         """
 
+        self.lastDescendantChangedSource = event.source
+
         # In Java comboboxes, when the list of options is popped up via
         # an up or down action, control (but not focus) goes to a LIST
         # object that manages the descendants.  So, we detect that here
@@ -168,9 +173,8 @@ class Script(default.Script):
             return
 
         if event.source.getRole() == pyatspi.ROLE_LIST:
-            combobox = self.getAncestor(event.source,
-                                        [pyatspi.ROLE_COMBO_BOX],
-                                        [pyatspi.ROLE_PANEL])
+            combobox = self.utilities.ancestorWithRole(
+                event.source, [pyatspi.ROLE_COMBO_BOX], [pyatspi.ROLE_PANEL])
             if combobox:
                 orca.visualAppearanceChanged(event, combobox)
                 return
@@ -187,10 +191,10 @@ class Script(default.Script):
         # ignore caret movement events caused by value changes and
         # just process the single value changed event.
         #
-        isSpinBox = self.isDesiredFocusedItem(event.source,
-                                              [pyatspi.ROLE_TEXT,
-                                               pyatspi.ROLE_PANEL,
-                                               pyatspi.ROLE_SPIN_BUTTON])
+        isSpinBox = self.utilities.hasMatchingHierarchy(
+            event.source, [pyatspi.ROLE_TEXT,
+                           pyatspi.ROLE_PANEL,
+                           pyatspi.ROLE_SPIN_BUTTON])
         if isSpinBox:
             if isinstance(orca_state.lastInputEvent,
                           input_event.KeyboardEvent):
@@ -211,13 +215,32 @@ class Script(default.Script):
         - event: the Event
         """
 
-        # Ignore selection in TREE and TABLE objects since they send us
-        # an active descendant changed event.
+        # Avoid doing this with objects that manage their descendants
+        # because they'll issue a descendant changed event. (Note: This
+        # equality check is intentional; utilities.isSameObject() is
+        # especially thorough with trees and tables, which is not
+        # performant.
         #
-        if event.source.getRole() in [pyatspi.ROLE_TREE, pyatspi.ROLE_TABLE]:
+        if event.source == self.lastDescendantChangedSource:
             return
 
-        default.Script.onSelectionChanged(self, event)
+        # We treat selected children as the locus of focus. When the
+        # selection changes in a list we want to update the locus of
+        # focus. If there is no selection, we default the locus of
+        # focus to the containing object.
+        #
+        if (event.source.getRole() in [pyatspi.ROLE_LIST,
+                                       pyatspi.ROLE_PAGE_TAB_LIST,
+                                       pyatspi.ROLE_TREE]) \
+            and event.source.getState().contains(pyatspi.STATE_FOCUSED):
+            newFocus = event.source
+            if event.source.childCount:
+                selection = event.source.querySelection()
+                if selection.nSelectedChildren > 0:
+                    newFocus = selection.getSelectedChild(0)
+            orca.setLocusOfFocus(event, newFocus)
+        else:
+            default.Script.onSelectionChanged(self, event)
 
     def onStateChanged(self, event):
         """Called whenever an object's state changes.
@@ -248,12 +271,12 @@ class Script(default.Script):
             for child in event.source:
                 # search the layered pane for a popup menu
                 if child.getRole() == pyatspi.ROLE_LAYERED_PANE:
-                    popup = self.findByRole(child,
-                                            pyatspi.ROLE_POPUP_MENU, False)
+                    popup = self.utilities.descendantsWithRole(
+                        child, pyatspi.ROLE_POPUP_MENU, False)
                     if len(popup) > 0:
                         # set the locus of focus to the armed menu item
-                        items = self.findByRole(popup[0],
-                                                pyatspi.ROLE_MENU_ITEM, False)
+                        items = self.utilities.descendantsWithRole(
+                            popup[0], pyatspi.ROLE_MENU_ITEM, False)
                         for item in items:
                             if item.getState().contains(pyatspi.STATE_ARMED):
                                 orca.setLocusOfFocus(event, item)
@@ -280,7 +303,10 @@ class Script(default.Script):
         # We'll ignore value changed events for Java's toggle buttons since
         # they also send a redundant object:state-changed:checked event.
         #
-        if event.source.getRole() == pyatspi.ROLE_TOGGLE_BUTTON:
+        ignoreRoles = [pyatspi.ROLE_TOGGLE_BUTTON,
+                       pyatspi.ROLE_RADIO_BUTTON,
+                       pyatspi.ROLE_CHECK_BOX]
+        if event.source.getRole() in ignoreRoles:
             return
 
         # Java's SpinButtons are the most caret movement happy thing
