@@ -186,7 +186,16 @@ userCustomizableSettings = [
     "wrappedStructuralNavigation",
     "presentRequiredState",
     "brailleRequiredStateString",
-    "speechRequiredStateString"
+    "speechRequiredStateString",
+    "chatMessageVerbosity",
+    "chatPrefixMessageWithName",
+    "chatAnnounceBuddyTyping",
+    "chatSeparateRoomHistories",
+    "enableFlashMessages",
+    "brailleFlashTime",
+    "flashIsPersistent",
+    "flashVerbosityLevel",
+    "messageVerbosityLevel",
 ]
 
 # The name of the module that hold the user interface for the main window
@@ -246,6 +255,8 @@ VERBOSITY_LEVEL_BRIEF   = 0
 VERBOSITY_LEVEL_VERBOSE = 1
 speechVerbosityLevel    = VERBOSITY_LEVEL_VERBOSE
 brailleVerbosityLevel   = VERBOSITY_LEVEL_VERBOSE
+flashVerbosityLevel     = VERBOSITY_LEVEL_VERBOSE
+messageVerbosityLevel   = VERBOSITY_LEVEL_VERBOSE
 
 BRAILLE_ROLENAME_STYLE_SHORT = 0 # three letter abbreviations
 BRAILLE_ROLENAME_STYLE_LONG  = 1 # full rolename
@@ -386,10 +397,20 @@ enableBrailleContext    = True
 #
 enableBrailleGrouping   = False
 
+# If True, enable braille flash messages. Note that braille or braille
+# monitor will also need to be enabled for this setting to work.
+#
+enableFlashMessages     = True
+
 # The timeout (in milliseconds) to use for messages flashed in braille.
 #
 brailleFlashTime        = 5000
 
+# If True, flash messages should continue to be displayed until some
+# other message comes along, or the user presses a key.
+#
+flashIsPersistent       = False
+
 # If True, enable braille monitor.
 #
 enableBrailleMonitor    = False
@@ -571,7 +592,7 @@ enableEchoByCharacter   = False
 #
 enableEchoByWord        = False
 
-# if True, enable word echo.
+# if True, enable Sentence echo.
 # Note that it is allowable for both enableEchoByWord and enableEchoBySentence
 # to be True.
 #
@@ -714,8 +735,8 @@ allTextAttributes = \
     "pixels-below-lines:; pixels-inside-wrap:; right-margin:; rise:; " \
     "scale:; size:; stretch:; strikethrough:false; style:normal; " \
     "text-decoration:none; text-rotation:0; text-shadow:none; " \
-    "underline:none; variant:; vertical-align:baseline; weight:400; " \
-    "wrap-mode:; writing-mode:lr-tb;"
+    "text-spelling:none; underline:none; variant:; " \
+    "vertical-align:baseline; weight:400; wrap-mode:; writing-mode:lr-tb;"
 
 # The default set of text attributes to speak to the user. Specific
 # application scripts (or individual users can override these values if
@@ -728,7 +749,7 @@ allTextAttributes = \
 enabledSpokenTextAttributes = \
     "size:; family-name:; weight:400; indent:0; underline:none; " \
     "strikethrough:false; justification:left; style:normal; " \
-    "paragraph-style:;"
+    "paragraph-style:; text-spelling:none;"
 
 # The default set of text attributes to be brailled for the user. Specific
 # application scripts (or individual users can override these values if
@@ -740,7 +761,8 @@ enabledSpokenTextAttributes = \
 
 enabledBrailledTextAttributes = \
     "size:; family-name:; weight:400; indent:0; underline:none; " \
-    "strikethrough:false; justification:left; style:normal;"
+    "strikethrough:false; justification:left; style:normal; " \
+    "text-spelling:none;"
 
 # Text Attributes Braille Indicator (see textAttributesBrailleIndicator).
 # The values represent the character to be used in the attrOr
@@ -818,6 +840,11 @@ cacheAccessibles        = True
 #
 learnModeEnabled        = False
 
+# Assists with list shortcuts mode (what you enter when you press 
+# Insert + H (double click) and exit when you press escape.
+#
+listShortcutsModeEnabled = False
+
 # The location of the user's preferences. By default this is ~/.orca.
 # It can be overridden by the Orca -d command line option.
 #
@@ -864,12 +891,10 @@ useBonoboMain           = True
 asyncMode               = True
 
 # A list of toolkits whose events we need to process synchronously.
-# The only one right now is the Java toolkit (see bug #531869), but
-# we put this here to allow more toolkits to be more easily added
-# and for Java to be removed if issues with asynchronous processing
-# of its events are ever resolved.
+# This was originally added for the Java toolkit (see bug #531869), but
+# we put this here to allow more toolkits to be more easily added.
 #
-synchronousToolkits     = ["J2SE-access-bridge"]
+synchronousToolkits     = []
 
 # If True, we output debug information for the event queue.  We
 # use this in addition to log level to prevent debug logic from
@@ -899,6 +924,26 @@ timeoutCallback         = None # Set by orca.py:init to orca.timeout
 #
 doubleClickTimeout = 0.5
 
+# Available options indicating which chat messages Orca should speak.
+#
+CHAT_SPEAK_ALL             = 0
+CHAT_SPEAK_ALL_IF_FOCUSED  = 1
+CHAT_SPEAK_FOCUSED_CHANNEL = 2
+
+chatMessageVerbosity = CHAT_SPEAK_ALL
+
+# Whether we prefix chat room messages with the name of the chat room.
+#
+chatSpeakRoomName = False
+
+# Whether we announce when a buddy is typing.
+#
+chatAnnounceBuddyTyping = False
+
+# Whether we provide chat room specific message histories.
+#
+chatRoomHistories = False
+
 # Obtain/set information regarding whether accessibility is enabled
 # or not.
 #
@@ -1146,6 +1191,10 @@ setScriptMapping(re.compile('Nereid'), "Banshee")
 #
 setScriptMapping(re.compile('ddu.py'), "ddu")
 
+# Strip off the extra 'py' that Gajim includes as part of its name.
+#
+setScriptMapping(re.compile('gajim.py'), "gajim")
+
 # Show deprecated messeges in debug output.
 # Set this to True to help find potential pyatspi porting problems
 #
